var KeystoreManager = Class.create({

    generateKeyUrl: null,
    generateKeyDialog: null,
    importKeyUrl: null,
    importKeyDialog: null,
    messageBar: null,

    _constructor: function(messageBar) {
        this.messageBar = messageBar;
    },

    registerGenerateKeyControl: function(control) {
        this.generateKeyUrl = control.href;
        Event.observe(control, "click", function(e) {
            this.generateKey();
            Event.stop(e);
        }.bindAsEventListener(this));
    },

    registerImportKeyControl: function(control) {
        this.importKeyUrl = control.href;
        Event.observe(control, "click", function(e) {
            this.importKey();
            Event.stop(e);
        }.bindAsEventListener(this));
    },

    generateKey: function() {
        if (this.generateKeyDialog == null) {
            this.generateKeyDialog = new GenerateKeyDialog(this.generateKeyUrl);
        }

        this._setGlobalMessage(null);
        this.generateKeyDialog.setVisible(true);
    },

    importKey: function() {
        if (this.importKeyDialog == null) {
            this.importKeyDialog = new ImportKeyDialog(this.importKeyUrl);
        }

        this._setGlobalMessage(null);
        this.importKeyDialog.setVisible(true);
    },

    onKeyGenerated: function(url, message) {
        if (this.generateKeyDialog != null) {
            this.generateKeyDialog.setVisible(false);
        }

        this._setGlobalMessage(message);
        var channel = new IFrameChannel("GeneratedKeyDownloadChannel");
        channel.open(url);
        channel.send("");
    },

    onKeyImported: function(message) {
        if (this.importKeyDialog != null) {
            this.importKeyDialog.setVisible(false);
        }

        this._setGlobalMessage(message);
    },

    _setGlobalMessage: function(text) {
        while (this.messageBar.hasChildNodes()) {
            this.messageBar.removeChild(this.messageBar.lastChild);
        }

        if (text != null) {
            this.messageBar.appendChild(this._createSuccessMessage(text));
        }
    },

    _createSuccessMessage: function(text) {
        var message = document.createElement("H3");
        message.appendChild(document.createTextNode(text));

        var result = document.createElement(Tag.DIV);
        Utils.addCssClass(result, "alertbox");
        result.appendChild(message);

        return result;
    }

});