var ManageItemsPane = Class.create({

    addButton: null,
    deleteButton: null,
    confirmDeleteDialog: null,
    selectionBoxs: null,
    selectAllBox: null,

    _constructor: function(listener) {
        this.selectionBoxs = [];

        this.confirmDeleteDialog = this._createConfirmDeleteDialog();
        this.confirmDeleteDialog.onSubmit = function() {
            this.setVisible(false);
            listener.onDelete.call(listener);
        }.bind(this.confirmDeleteDialog);

        this._compose();
        this._bindEvents();
    },

    getSelectedCount: function() {
        var count = 0;
        for (var i = 0, size = this.selectionBoxs.length; i < size; ++i) {
            if (this.selectionBoxs[i].checked) {
                count++;
            }
        }
        return count;
    },

    _compose: function() {
        this.addButton = $("additem");
        this.deleteButton = $("deleteitem");
        this.selectAllBox = $("selectall");
        this.selectionBoxs = Utils.getFormInputs($("itemsform"), Tag.INPUT_TYPE_CHECKBOX, "name");
        Utils.setEnabled(this.selectAllBox, this.selectionBoxs.length != 0);
    },

    _handleDelete: function(event) {
        if (this.getSelectedCount() != 0) {
            this._displayConfirmDelete();
        }
        Event.stop(event);
    },

    _handleSelectAll: function() {
        var selected = Boolean.toBoolean($F(this.selectAllBox));

        for (var i = 0, size = this.selectionBoxs.length; i < size; ++i) {
            this.selectionBoxs[i].checked = selected;
        }

        this._update();
    },

    _displayConfirmDelete: function() {
        this.confirmDeleteDialog.setVisible(true);
    },

    _createConfirmDeleteDialog: function() {
        var dialog = new ModalDialog("DeleteItemsConfirmDialog");
        var content = dialog.getContent();

        var messagePanel = document.createElement(Tag.PARAGRAPH);
        Utils.setStyle(messagePanel, "font-weight:bold;");
        messagePanel.appendChild(document.createTextNode(ManageItemsPane.Messages.CONFIRM_DELETE));
        content.appendChild(messagePanel);

        dialog.addButton(ModalDialog.BUTTON_OK, ManageItemsPane.Buttons.OK);
        dialog.addButton(ModalDialog.BUTTON_CANCEL, ManageItemsPane.Buttons.CANCEL, function() {
            this.setVisible(false);
        }.bind(dialog));

        return dialog;
    },

    _update: function() {
        var count = this.getSelectedCount();
        this.selectAllBox.checked = (this.selectionBoxs.length == count);
        Utils.setEnabled(this.deleteButton, count != 0);
    },

    _bindEvents: function () {
        Event.observe(this.selectAllBox, "click", this._handleSelectAll.bind(this));
        Event.observe(this.deleteButton, "click", this._handleDelete.bindAsEventListener(this));
        var selectionHandler = this._update.bind(this);

        for (var i = 0; i < this.selectionBoxs.length; ++i) {
            Event.observe(this.selectionBoxs[i], "click", selectionHandler);
        }
    }

});

ManageItemsPane.Buttons = {OK: "OK", CANCEL: "Cancel"};
ManageItemsPane.Messages = {CONFIRM_DELETE: "Delete selected item(s)?"};